@@ -125,7 +125,7 @@ class Base(object):
 
     @staticmethod
     def bind_conditions(sql, conditions, or_cond):
-        print(sql)
+        # print(sql)
         if conditions is None:
             conditions = []
         if or_cond is None:
